This function gives the posterior distribution of the number of fatalities based on the number of carcasses counted during carcass searches and the probability of detecting a carcass. The function uses the theorem of Bayes.
posteriorN(p, nf = 0, maxN = 1000, ci.int = 0.95, plot = TRUE,
dist = FALSE)vector of length 2 containing the lower and upper limit of the interval specified in the argument ci.int
median of the posterior distribution of the number of fatalities
Horvitz-Thompson estimate, i.e. nf/p
posterior density for each element in 0:maxN number of fatalities
probability of finding a carcass. This probability can be obtained by e.g. pkorner, phuso or perickson.
the number of carcasses found
the maximal number of fatalities for which a posterior densitiy should be given. It should be higher than the upper tail (density larger 0.0001) of the posterior distribution (there is a warning if not). If maxN is lower than the lower edge of the posterior distribution, an error is produced.
length of the credible interval that should be given. Default is 0.95.
if TRUE the posterior distribution is plotted
if TRUE the posterior density is given for all elements in 0:maxN
Fraenzi Korner-Nievergelt
Korner-Nievergelt F, Korner-Nievergelt P, Behr O, Niermann I, Brinkmann R, Hellriegel B (2011) A new method to determine bird and bat fatality at wind energy turbines from carcass searches. Wildlife Biology 17: 350-363
estimateN
posteriorN(p=0.5, nf=3, dist=TRUE, maxN=15)
Run the code above in your browser using DataLab